@@ -1,4 +1,4 @@
-// Copyright (C) 2017-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2017-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -15,9 +15,7 @@
 #include <asiolink/testutils/test_server_unix_socket.h>
 #include <cc/command_interpreter.h>
 #include <cc/data.h>
-#include <config/unix_command_config.h>
 #include <process/testutils/d_test_stubs.h>
-#include <util/filesystem.h>
 #include <boost/pointer_cast.hpp>
 #include <gtest/gtest.h>
 #include <testutils/sandbox.h>
@@ -30,8 +28,6 @@ using namespace isc::agent;
 using namespace isc::asiolink;
 using namespace isc::data;
 using namespace isc::process;
-using namespace isc::config;
-using namespace isc::util;
 
 namespace {
 
@@ -54,7 +50,6 @@ public:
         : DControllerTest(CtrlAgentController::instance),
           mgr_(CtrlAgentCommandMgr::instance()) {
         mgr_.deregisterAll();
-        setSocketTestPath();
         removeUnixSocketFile();
         initProcess();
     }
@@ -65,7 +60,6 @@ public:
     virtual ~CtrlAgentCommandMgrTest() {
         mgr_.deregisterAll();
         removeUnixSocketFile();
-        resetSocketPath();
     }
 
     /// @brief Verifies received answer
@@ -100,34 +94,31 @@ public:
         std::vector<ElementPtr> answer_list = answer->listValue();
 
         ASSERT_EQ(expected_codes.size(), answer_list.size());
+        size_t count = 0;
         // Check all answers.
-        for (auto ans = answer_list.cbegin(); ans != answer_list.cend();
-             ++ans) {
+        for (auto const& ans : answer_list) {
             ConstElementPtr text;
-            ASSERT_NO_THROW(text = isc::config::parseAnswer(status_code, *ans));
-            EXPECT_EQ(expected_codes[std::distance(answer_list.cbegin(), ans)],
-                      status_code)
+            ASSERT_NO_THROW(text = isc::config::parseAnswer(status_code, ans));
+            EXPECT_EQ(expected_codes[count], status_code)
                 << "answer contains text: " << text->stringValue();
+            count++;
         }
     }
 
     /// @brief Returns socket file path.
+    ///
+    /// If the KEA_SOCKET_TEST_DIR environment variable is specified, the
+    /// socket file is created in the location pointed to by this variable.
+    /// Otherwise, it is created in the build directory.
     std::string unixSocketFilePath() {
-        return (UnixCommandConfig::getSocketPath() + "/test-socket");
-    }
-
-    /// @brief Sets the path in which the socket can be created.
-    /// @param explicit_path path to use as the socket path.
-    void setSocketTestPath(const std::string explicit_path = "") {
-        auto path = UnixCommandConfig::getSocketPath(true, (!explicit_path.empty() ?
-                                                     explicit_path : TEST_DATA_BUILDDIR));
-        UnixCommandConfig::setSocketPathPerms(file::getPermissions(path));
-    }
-
-    /// @brief Resets the socket path to the default.
-    void resetSocketPath() {
-        UnixCommandConfig::getSocketPath(true);
-        UnixCommandConfig::setSocketPathPerms();
+        std::string socket_path;
+        const char* env = getenv("KEA_SOCKET_TEST_DIR");
+        if (env) {
+            socket_path = std::string(env) + "/test-socket";
+        } else {
+            socket_path = sandbox.join("test-socket");
+        }
+        return (socket_path);
     }
 
     /// @brief Removes unix socket descriptor.
@@ -167,7 +158,7 @@ public:
         ASSERT_TRUE(ctx);
 
         ElementPtr control_socket = Element::createMap();
-        control_socket->set("validated-socket-name",
+        control_socket->set("socket-name",
                             Element::create(unixSocketFilePath()));
         ctx->setControlSocketInfo(control_socket, service);
     }
@@ -257,7 +248,7 @@ public:
 
         // We have some cancelled operations for which we need to invoke the
         // handlers with the operation_aborted error code.
-        getIOService()->get_io_service().reset();
+        getIOService()->restart();
         getIOService()->poll();
 
         EXPECT_EQ(expected_responses, server_socket_->getResponseNum());
@@ -422,7 +413,7 @@ TEST_F(CtrlAgentCommandMgrTest, forwardListCommands) {
 
     // We have some cancelled operations for which we need to invoke the
     // handlers with the operation_aborted error code.
-    getIOService()->get_io_service().reset();
+    getIOService()->restart();
     getIOService()->poll();
 
     // Answer of 3 is specific to the stub response we send when the
