@@ -239,9 +239,9 @@ public:
         // Run as long as the timeout hasn't occurred and the interrupting
         // condition is not specified or not met.
         while (!stopped && (!cond || !cond())) {
-            io_service->run_one();
+            io_service->runOne();
         }
-        io_service->get_io_service().reset();
+        io_service->restart();
     }
 
     /// @brief This test verifies that the timer used to fetch the configuration
@@ -398,15 +398,17 @@ TEST_F(JSONFileBackendTest, jsonFile) {
         "\"renew-timer\": 1000, "
         "\"subnet4\": [ { "
         "    \"pools\": [ { \"pool\": \"192.0.2.1 - 192.0.2.100\" } ],"
+        "    \"id\": 1, "
         "    \"subnet\": \"192.0.2.0/24\" "
         " },"
         " {"
         "    \"pools\": [ { \"pool\": \"192.0.3.101 - 192.0.3.150\" } ],"
         "    \"subnet\": \"192.0.3.0/24\", "
-        "    \"id\": 0 "
+        "    \"id\": 2 "
         " },"
         " {"
         "    \"pools\": [ { \"pool\": \"192.0.4.101 - 192.0.4.150\" } ],"
+        "    \"id\": 3, "
         "    \"subnet\": \"192.0.4.0/24\" "
         " } ],"
         "\"valid-lifetime\": 4000 }"
@@ -483,6 +485,7 @@ TEST_F(JSONFileBackendTest, hashComments) {
         "# comments in the middle should be ignored, too\n"
         "\"subnet4\": [ { "
         "    \"pools\": [ { \"pool\": \"192.0.2.0/24\" } ],"
+        "    \"id\": 1, "
         "    \"subnet\": \"192.0.2.0/22\" "
         " } ],"
         "\"valid-lifetime\": 4000 }"
@@ -534,6 +537,7 @@ TEST_F(JSONFileBackendTest, cppLineComments) {
         "// comments in the middle should be ignored, too\n"
         "\"subnet4\": [ { "
         "    \"pools\": [ { \"pool\": \"192.0.2.0/24\" } ],"
+        "    \"id\": 1, "
         "    \"subnet\": \"192.0.2.0/22\" "
         " } ],"
         "\"valid-lifetime\": 4000 }"
@@ -585,6 +589,7 @@ TEST_F(JSONFileBackendTest, cBlockComments) {
         "/* comments in the middle should be ignored, too*/\n"
         "\"subnet4\": [ { "
         "    \"pools\": [ { \"pool\": \"192.0.2.0/24\" } ],"
+        "    \"id\": 1, "
         "    \"subnet\": \"192.0.2.0/22\" "
         " } ],"
         "\"valid-lifetime\": 4000 }"
@@ -637,6 +642,7 @@ TEST_F(JSONFileBackendTest, include) {
     string include = "\n"
         "\"subnet4\": [ { "
         "    \"pools\": [ { \"pool\": \"192.0.2.0/24\" } ],"
+        "    \"id\": 1, "
         "    \"subnet\": \"192.0.2.0/22\" "
         " } ]\n";
 
@@ -683,6 +689,7 @@ TEST_F(JSONFileBackendTest, recursiveInclude) {
         "\"renew-timer\": 1000, \n"
         "\"subnet4\": [ { "
         "    \"pools\": [ { \"pool\": \"192.0.2.0/24\" } ],"
+        "    \"id\": 1, "
         "    \"subnet\": \"192.0.2.0/22\" "
         " } ],"
         "\"valid-lifetime\": 4000 }"
@@ -727,6 +734,7 @@ TEST_F(JSONFileBackendTest, configBroken) {
         "\"renew-timer\": 1000, "
         "\"subnet4\": [ { "
         "    \"pool\": [ \"2001:db8::/80\" ],"
+        "    \"id\": 1, "
         "    \"subnet\": \"2001:db8::/64\" "
         " } ]}";
 
