@@ -1,16 +1,8 @@
-// Copyright (C) 2012 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2017 Internet Systems Consortium, Inc. ("ISC")
 //
-// Permission to use, copy, modify, and/or distribute this software for any
-// purpose with or without fee is hereby granted, provided that the above
-// copyright notice and this permission notice appear in all copies.
-//
-// THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
-// REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
-// AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
-// INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
-// LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
-// OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
-// PERFORMANCE OF THIS SOFTWARE.
+// This Source Code Form is subject to the terms of the Mozilla Public
+// License, v. 2.0. If a copy of the MPL was not distributed with this
+// file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 #include <config.h>
 #include <iostream>
@@ -22,6 +14,8 @@
 #include <dhcp/option.h>
 #include <dhcp/dhcp4.h>
 
+#include <boost/scoped_ptr.hpp>
+
 #include "../localized_option.h"
 #include "../perf_pkt4.h"
 
@@ -74,6 +68,7 @@ public:
             255, 255, 255, 255,     // giaddr
         };
 
+        // cppcheck-suppress variableScope
         uint8_t v4Opts[] = {
             DHO_HOST_NAME, 3, 0,   1,  2,  // Host name option.
             DHO_BOOT_SIZE, 3, 10, 11, 12,  // Boot file size option
@@ -114,7 +109,7 @@ public:
 TEST_F(PerfPkt4Test, Constructor) {
     // Initialize some dummy payload.
     uint8_t data[250];
-    for (int i = 0; i < 250; ++i) {
+    for (uint8_t i = 0; i < 250; ++i) {
         data[i] = i;
     }
 
@@ -349,12 +344,12 @@ TEST_F(PerfPkt4Test, PackTransactionId) {
 }
 
 TEST_F(PerfPkt4Test, UnpackTransactionId) {
-    // Initialize packet data, lebgth 268, zeros only.
+    // Initialize packet data, length 268, zeros only.
     std::vector<uint8_t> in_data(268, 0);
 
     // Assume that transaction id is at offset 100.
     // Fill 4 bytes at offset 100 with dummy transaction id.
-    for (int i = 100; i < 104; ++i) {
+    for (uint8_t i = 100; i < 104; ++i) {
         in_data[i] = i - 99;
     }
 
@@ -382,11 +377,11 @@ TEST_F(PerfPkt4Test, UnpackTransactionId) {
 }
 
 TEST_F(PerfPkt4Test, Writes) {
-    // Initialize intput buffer with 260 elements set to value 1.
+    // Initialize input buffer with 260 elements set to value 1.
     dhcp::OptionBuffer in_data(260, 1);
     // Initialize buffer to be used for write: 1,2,3,4,...,9
     dhcp::OptionBuffer write_buf(10);
-    for (int i = 0; i < write_buf.size(); ++i) {
+    for (size_t i = 0; i < write_buf.size(); ++i) {
         write_buf[i] = i;
     }
     // Create packet from the input buffer.
