@@ -1,4 +1,4 @@
-// Copyright (C) 2017-2021 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2017-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -20,6 +20,9 @@
 #include <hooks/hooks.h>
 #include <process/daemon.h>
 
+#include <sstream>
+#include <string>
+
 namespace isc {
 namespace ha {
 
@@ -34,6 +37,7 @@ using namespace isc::dhcp;
 using namespace isc::ha;
 using namespace isc::hooks;
 using namespace isc::process;
+using namespace std;
 
 extern "C" {
 
@@ -44,13 +48,25 @@ int dhcp4_srv_configured(CalloutHandle& handle) {
     try {
         isc::asiolink::IOServicePtr io_service;
         handle.getArgument("io_context", io_service);
+        if (!io_service) {
+            // Should not happen!
+            handle.setStatus(isc::hooks::CalloutHandle::NEXT_STEP_DROP);
+            const string error("Error: io_context is null");
+            handle.setArgument("error", error);
+            return (1);
+        }
         isc::dhcp::NetworkStatePtr network_state;
         handle.getArgument("network_state", network_state);
-        impl->startService(io_service, network_state, HAServerType::DHCPv4);
+        impl->startServices(io_service, network_state, HAServerType::DHCPv4);
 
     } catch (const std::exception& ex) {
         LOG_ERROR(ha_logger, HA_DHCP4_START_SERVICE_FAILED)
             .arg(ex.what());
+        handle.setStatus(isc::hooks::CalloutHandle::NEXT_STEP_DROP);
+        ostringstream os;
+        os << "Error: " << ex.what();
+        string error(os.str());
+        handle.setArgument("error", error);
         return (1);
     }
     return (0);
@@ -77,6 +93,28 @@ int buffer4_receive(CalloutHandle& handle) {
     return (0);
 }
 
+/// @brief subnet4_select callout implementation.
+///
+/// @param handle callout handle.
+int subnet4_select(CalloutHandle& handle) {
+    CalloutHandle::CalloutNextStep status = handle.getStatus();
+    if (status == CalloutHandle::NEXT_STEP_DROP) {
+        return (0);
+    }
+
+    try {
+        impl->subnet4Select(handle);
+
+    } catch (const std::exception& ex) {
+        LOG_ERROR(ha_logger, HA_SUBNET4_SELECT_FAILED)
+            .arg(ex.what());
+        return (1);
+    }
+
+    return (0);
+}
+
+
 /// @brief leases4_committed callout implementation.
 ///
 /// @param handle callout handle.
@@ -99,6 +137,28 @@ int leases4_committed(CalloutHandle& handle) {
     return (0);
 }
 
+/// @brief lease4_server_decline callout implementation.
+///
+/// @param handle callout handle.
+int lease4_server_decline(CalloutHandle& handle) {
+    CalloutHandle::CalloutNextStep status = handle.getStatus();
+    if (status == CalloutHandle::NEXT_STEP_DROP ||
+        status == CalloutHandle::NEXT_STEP_SKIP) {
+        return (0);
+    }
+
+    try {
+        impl->lease4ServerDecline(handle);
+    } catch (const std::exception& ex) {
+        LOG_ERROR(ha_logger, HA_LEASE4_SERVER_DECLINE_FAILED)
+            .arg(ex.what());
+        return (1);
+    }
+
+    return (0);
+}
+
+
 /// @brief dhcp6_srv_configured callout implementation.
 ///
 /// @param handle callout handle.
@@ -106,13 +166,25 @@ int dhcp6_srv_configured(CalloutHandle& handle) {
     try {
         isc::asiolink::IOServicePtr io_service;
         handle.getArgument("io_context", io_service);
+        if (!io_service) {
+            // Should not happen!
+            handle.setStatus(isc::hooks::CalloutHandle::NEXT_STEP_DROP);
+            const string error("Error: io_context is null");
+            handle.setArgument("error", error);
+            return (1);
+        }
         isc::dhcp::NetworkStatePtr network_state;
         handle.getArgument("network_state", network_state);
-        impl->startService(io_service, network_state, HAServerType::DHCPv6);
+        impl->startServices(io_service, network_state, HAServerType::DHCPv6);
 
     } catch (const std::exception& ex) {
         LOG_ERROR(ha_logger, HA_DHCP6_START_SERVICE_FAILED)
             .arg(ex.what());
+        handle.setStatus(isc::hooks::CalloutHandle::NEXT_STEP_DROP);
+        ostringstream os;
+        os << "Error: " << ex.what();
+        string error(os.str());
+        handle.setArgument("error", error);
         return (1);
     }
     return (0);
@@ -140,6 +212,27 @@ int buffer6_receive(CalloutHandle& handle) {
     return (0);
 }
 
+/// @brief subnet6_select callout implementation.
+///
+/// @param handle callout handle.
+int subnet6_select(CalloutHandle& handle) {
+    CalloutHandle::CalloutNextStep status = handle.getStatus();
+    if (status == CalloutHandle::NEXT_STEP_DROP) {
+        return (0);
+    }
+
+    try {
+        impl->subnet6Select(handle);
+
+    } catch (const std::exception& ex) {
+        LOG_ERROR(ha_logger, HA_SUBNET6_SELECT_FAILED)
+            .arg(ex.what());
+        return (1);
+    }
+
+    return (0);
+}
+
 /// @brief leases6_committed callout implementation.
 ///
 /// @param handle callout handle.
@@ -283,6 +376,18 @@ int ha_reset_command(CalloutHandle& handle) {
     return (0);
 }
 
+/// @brief ha-sync-complete-notify command handler implementation.
+int sync_complete_notify_command(CalloutHandle& handle) {
+    try {
+        impl->syncCompleteNotifyHandler(handle);
+    } catch (const std::exception& ex) {
+        LOG_ERROR(ha_logger, HA_SYNC_COMPLETE_NOTIFY_HANDLER_FAILED)
+            .arg(ex.what());
+    }
+
+    return (0);
+}
+
 /// @brief This function is called when the library is loaded.
 ///
 /// @param handle library handle
@@ -321,6 +426,7 @@ int load(LibraryHandle& handle) {
         handle.registerCommandCallout("ha-maintenance-start", maintenance_start_command);
         handle.registerCommandCallout("ha-maintenance-cancel", maintenance_cancel_command);
         handle.registerCommandCallout("ha-reset", ha_reset_command);
+        handle.registerCommandCallout("ha-sync-complete-notify", sync_complete_notify_command);
 
     } catch (const std::exception& ex) {
         LOG_ERROR(ha_logger, HA_CONFIGURATION_FAILED)
