@@ -1,4 +1,4 @@
-// Copyright (C) 2015-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2015-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -13,7 +13,6 @@
 #include <asiolink/unix_domain_socket_acceptor.h>
 #include <asiolink/unix_domain_socket_endpoint.h>
 #include <config/command_mgr.h>
-#include <config/unix_command_config.h>
 #include <cc/data.h>
 #include <cc/command_interpreter.h>
 #include <cc/json_feed.h>
@@ -263,9 +262,8 @@ public:
 
     /// @brief Stops all connections which are allowed to stop.
     void stopAll() {
-        for (auto conn = connections_.begin(); conn != connections_.end();
-             ++conn) {
-            (*conn)->stop();
+        for (auto const& conn : connections_) {
+            conn->stop();
         }
         connections_.clear();
     }
@@ -548,11 +546,7 @@ CommandMgrImpl::openCommandSocket(const isc::data::ConstElementPtr& socket_info)
         isc_throw(BadSocketInfo, "'socket-name' parameter expected to be a string");
     }
 
-    try {
-        socket_name_ = UnixCommandConfig::validatePath(name->stringValue());
-    } catch (const std::exception& ex) {
-        isc_throw(BadSocketInfo, "'socket-name' is invalid: " << ex.what());
-    }
+    socket_name_ = name->stringValue();
 
     // First let's open lock file.
     std::string lock_name = getLockName();
@@ -592,8 +586,6 @@ CommandMgrImpl::openCommandSocket(const isc::data::ConstElementPtr& socket_info)
         doAccept();
 
     } catch (const std::exception& ex) {
-        close(lock_fd);
-        static_cast<void>(::remove(getLockName().c_str()));
         isc_throw(SocketError, ex.what());
     }
 }
