@@ -1,16 +1,8 @@
-// Copyright (C) 2011, 2014, 2015  Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2011-2024 Internet Systems Consortium, Inc. ("ISC")
 //
-// Permission to use, copy, modify, and/or distribute this software for any
-// purpose with or without fee is hereby granted, provided that the above
-// copyright notice and this permission notice appear in all copies.
-//
-// THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
-// REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
-// AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
-// INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
-// LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
-// OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
-// PERFORMANCE OF THIS SOFTWARE.
+// This Source Code Form is subject to the terms of the Mozilla Public
+// License, v. 2.0. If a copy of the MPL was not distributed with this
+// file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 #ifndef ISC_CRYPTO_H
 #define ISC_CRYPTO_H
@@ -20,7 +12,7 @@
 #include <exceptions/exceptions.h>
 
 #include <boost/noncopyable.hpp>
-#include <boost/scoped_ptr.hpp>
+#include <boost/shared_ptr.hpp>
 
 #include <memory>
 
@@ -44,12 +36,18 @@ enum HashAlgorithm {
 
 };
 
-// Forward declaration for createHash()
+/// \brief Forward declaration for createHash()
 class Hash;
 
-// Forward declaration for createHMAC()
+/// \brief Forward declaration for createHMAC()
 class HMAC;
 
+/// \brief Forward declaration for getRNG()
+class RNG;
+
+/// \brief Type representing the pointer to the RNG.
+typedef boost::shared_ptr<RNG> RNGPtr;
+
 /// General exception class that is the base for all crypto-related
 /// exceptions
 class CryptoLinkError : public Exception {
@@ -92,9 +90,15 @@ public:
         CryptoLinkError(file, line, what) {}
 };
 
-/// Forward declaration for pimpl
+/// \brief Forward declarations for CryptoLink pimpl.
 class CryptoLinkImpl;
 
+/// \brief Type representing the pointer to the CryptoLinkImpl.
+typedef boost::shared_ptr<CryptoLinkImpl> CryptoLinkImplPtr;
+
+/// \brief Forward declarations for RNG pimpl.
+class RNGImpl;
+
 /// \brief Singleton entry point and factory class
 ///
 /// This is a singleton class that serves as the entry point to
@@ -103,10 +107,7 @@ class CryptoLinkImpl;
 ///
 /// There is only one way to access it, through getCryptoLink(), which
 /// returns a reference to the initialized library. On the first call,
-/// it will be initialized automatically. You can however initialize it
-/// manually through a call to initialize(), before your first call
-/// to getCryptoLink. Any subsequent call to initialize() will be a
-/// noop.
+/// it will be initialized automatically.
 ///
 /// In order for the CryptoLink library to be sure that the underlying
 /// library has been initialized, and because we do not want to add
@@ -148,19 +149,6 @@ public:
     /// \return Reference to the singleton instance
     static CryptoLink& getCryptoLink();
 
-    /// \brief Initialize the library manually
-    ///
-    /// If the library has already been initialized (either by a call
-    /// to initialize() or automatically in getCryptoLink()), this
-    /// function does nothing.
-    ///
-    /// \note A call to initialize() is not strictly necessary with
-    /// the current implementation.
-    ///
-    /// \exception InitializationError if initialization fails
-    ///
-    static void initialize();
-
     /// \brief Get version string
     static std::string getVersion();
 
@@ -217,17 +205,41 @@ public:
     HMAC* createHMAC(const void* secret, size_t secret_len,
                      const HashAlgorithm hash_algorithm);
 
+    /// \brief Get the global RNG
+    ///
+    /// \exception NotImplemented if the method was not implemented
+    ///                           in a derived class
+    /// \exception LibraryError if there was any unexpected exception
+    ///                         in the underlying library
+    virtual RNGPtr const& getRNG() const;
+
 private:
-    // To enable us to use an optional explicit initialization call,
-    // the 'real' instance getter is private
-    static CryptoLink& getCryptoLinkInternal();
+    /// \brief Initialize the library
+    ///
+    /// If the library has already been initialized (either by a call
+    /// to initialize() or automatically in getCryptoLink()), this
+    /// function does nothing.
+    ///
+    /// \note A call to initialize() is not strictly necessary with
+    /// the current implementation.
+    ///
+    /// \exception InitializationError if initialization fails
+    ///
+    /// \param c the CryptoLink singleton instance which is being initialized.
+    void initialize(CryptoLink& c);
 
     // To prevent people constructing their own, we make the constructor
     // private too.
-    CryptoLink() : impl_(NULL) {}
+    CryptoLink() {
+        initialize(*this);
+    }
     ~CryptoLink();
 
-    CryptoLinkImpl* impl_;
+    /// \brief Smart pointer holding the implementation.
+    CryptoLinkImplPtr impl_;
+
+    /// \brief Smart pointer holding the RNG.
+    RNGPtr rng_;
 };
 
 } // namespace cryptolink
