@@ -1,4 +1,4 @@
-// Copyright (C) 2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2023-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -8,12 +8,19 @@
 #define OPTION4_DNR_H
 
 #include <asiolink/io_address.h>
+#include <boost/assign.hpp>
+#include <boost/bimap.hpp>
 #include <dhcp/dhcp4.h>
 #include <dhcp/dhcp6.h>
 #include <dhcp/option.h>
 #include <dhcp/option_data_types.h>
 #include <dns/name.h>
+#include <util/encode/utf8.h>
+#include <util/strutil.h>
 
+#include <map>
+#include <set>
+#include <string>
 #include <unordered_set>
 
 namespace isc {
@@ -45,13 +52,15 @@ public:
 /// @c Option6Dnr class can derive from this @c DnrInstance class, whereas @c Option4Dnr class
 /// should have a container of @c DnrInstance's.
 ///
-/// DNR Instance Data Format has been defined in the @c draft-ietf-add-dnr (to be replaced
-/// with published RFC).
+/// DNR Instance Data Format has been defined in the @c RFC9463.
 class DnrInstance {
 public:
     /// @brief A Type defined for container holding IP addresses.
     typedef std::vector<isc::asiolink::IOAddress> AddressContainer;
 
+    /// @brief A Type defined for boost Bimap holding SvcParamKeys.
+    typedef boost::bimap<std::string, uint16_t> SvcParamsMap;
+
     /// @brief Size in octets of Service Priority field.
     static const uint8_t SERVICE_PRIORITY_SIZE = 2;
 
@@ -62,46 +71,37 @@ public:
     /// included IP addresses.
     static const std::unordered_set<std::string> FORBIDDEN_SVC_PARAMS;
 
+    /// @brief Service parameters, used in DNR options in DHCPv4 and DHCPv6, but also in RA and DNS
+    ///
+    /// The IANA registry is maintained at https://www.iana.org/assignments/dns-svcb/dns-svcb.xhtml
+    static const SvcParamsMap SVC_PARAMS;
+
+    /// @brief Ordered set of supported SvcParamKeys.
+    ///
+    /// As per RFC9463 Section 3.1.5:
+    /// The following service parameters MUST be supported by a DNR implementation:
+    /// SvcParamKey=1 alpn: Used to indicate the set of supported protocols (Section 7.1 of
+    /// [RFC9460]).
+    /// SvcParamKey=3 port: Used to indicate the target port number for the encrypted DNS connection
+    /// (Section 7.2 of [RFC9460]).
+    ///
+    /// In addition, the following service parameter is RECOMMENDED to be supported by a DNR
+    /// implementation:
+    /// SvcParamKey=7 dohpath: Used to supply a relative DoH URI Template
+    /// (Section 5.1 of [RFC9461]).
+    static const std::set<uint8_t> SUPPORTED_SVC_PARAMS;
+
+    /// @brief Possible ALPN protocol IDs.
+    ///
+    /// The IANA registry is maintained at
+    /// https://www.iana.org/assignments/tls-extensiontype-values/tls-extensiontype-values.xhtml#alpn-protocol-ids
+    static const std::unordered_set<std::string> ALPN_IDS;
+
     /// @brief Constructor of the empty DNR Instance.
     ///
     /// @param universe either V4 or V6 Option universe
     explicit DnrInstance(Option::Universe universe);
 
-    /// @brief Constructor of the DNR Instance with all fields from params.
-    ///
-    /// Constructor of the DNR Instance where all fields
-    /// i.e. Service priority, ADN, IP address(es) and Service params
-    /// are provided as ctor parameters.
-    ///
-    /// @param universe either V4 or V6 Option universe
-    /// @param service_priority Service priority
-    /// @param adn ADN FQDN
-    /// @param ip_addresses Container of IP addresses
-    /// @param svc_params Service Parameters
-    ///
-    /// @throw InvalidOptionDnrDomainName Thrown in case of any issue with parsing ADN
-    /// @throw InvalidOptionDnrSvcParams Thrown when @c checkSvcParams(from_wire_data) throws
-    /// @throw OutOfRange Thrown in case of no IP addresses found or when IP addresses length
-    /// is too big
-    DnrInstance(Option::Universe universe,
-                uint16_t service_priority,
-                const std::string& adn,
-                const AddressContainer& ip_addresses,
-                const std::string& svc_params);
-
-    /// @brief Constructor of the DNR Instance in ADN only mode.
-    ///
-    /// Constructor of the DNR Instance in ADN only mode
-    /// i.e. only Service priority and ADN FQDN
-    /// are provided as ctor parameters.
-    ///
-    /// @param universe either V4 or V6 Option universe
-    /// @param service_priority Service priority
-    /// @param adn ADN FQDN
-    ///
-    /// @throw InvalidOptionDnrDomainName Thrown in case of any issue with parsing ADN
-    DnrInstance(Option::Universe universe, uint16_t service_priority, const std::string& adn);
-
     /// @brief Default destructor.
     virtual ~DnrInstance() = default;
 
@@ -164,11 +164,11 @@ public:
         return (ip_addresses_);
     }
 
-    /// @brief Getter of the @c svc_params_ field.
+    /// @brief Returns a reference to the buffer holding SvcParam data.
     ///
-    /// @return Returns Service Parameters as a string.
-    const std::string& getSvcParams() const {
-        return (svc_params_);
+    /// @return a reference to the Service Parameters buffer
+    const OptionBuffer& getSvcParams() const {
+        return (svc_params_buf_);
     }
 
     /// @brief Returns minimal length of the DNR instance data (without headers) in octets.
@@ -205,19 +205,6 @@ public:
         return (adn_only_mode_);
     }
 
-    /// @brief Sets Authentication domain name from given string.
-    ///
-    /// Sets FQDN of the encrypted DNS resolver from given string.
-    /// It may throw an exception if parsing of the FQDN fails or if
-    /// provided FQDN length is bigger than uint16_t Max.
-    /// It also calculates and sets value of Addr length field.
-    ///
-    /// @param adn string representation of ADN FQDN
-    ///
-    /// @throw InvalidOptionDnrDomainName Thrown in case of any issue with parsing ADN
-    /// from given string.
-    void setAdn(const std::string& adn);
-
     /// @brief Setter of the @c adn_only_mode_ field.
     ///
     /// @param adn_only_mode enabled/disabled setting
@@ -225,6 +212,15 @@ public:
         adn_only_mode_ = adn_only_mode;
     }
 
+    /// @brief Setter of the @c dnr_instance_data_length_ field.
+    ///
+    /// Size is calculated basing on set Service Priority, ADN, IP address(es) and SvcParams.
+    /// This should be called after all fields are set.
+    /// This is only used for DHCPv4 Encrypted DNS %Option.
+    void setDnrInstanceDataLength() {
+        dnr_instance_data_length_ = dnrInstanceLen();
+    }
+
     /// @brief Writes the ADN FQDN in the wire format into a buffer.
     ///
     /// The Authentication Domain Name - fully qualified domain name of the encrypted
@@ -291,47 +287,46 @@ public:
     /// Addr Len not divisible by 4, Addr Len is 0.
     virtual void unpackAddresses(OptionBufferConstIter& begin, OptionBufferConstIter end);
 
-    /// @brief Unpacks Service Parameters from wire data buffer and stores it in @c svc_params_.
-    ///
-    /// It may throw in case of malformed data detected during parsing.
+    /// @brief Unpacks Service Parameters from wire data buffer and stores it in @c svc_params_buf_.
     ///
     /// @param begin beginning of the buffer from which the field will be read
     /// @param end end of the buffer from which the field will be read
+    ///
+    /// @throw OutOfRange Thrown when truncated data is detected.
+    /// @throw InvalidOptionDnrSvcParams Thrown when invalid SvcParams syntax is detected.
     void unpackSvcParams(OptionBufferConstIter& begin, OptionBufferConstIter end);
 
-    /// @brief Checks SvcParams field if encoded correctly and throws in case of issue found.
-    ///
-    /// The field should be encoded following the rules in
-    /// Section 2.1 of [I-D.ietf-dnsop-svcb-https]. SvcParams are
-    /// a whitespace-separated list, with each SvcParam consisting of
-    /// a SvcParamKey=SvcParamValue pair or a standalone SvcParamKey.
-    ///
-    /// @note It is user's responsibility to provide correct configuration
-    /// of @c SvcParams as described in Section 2.1 of [I-D.ietf-dnsop-svcb-https].
-    /// Currently, SvcParamValue is not verified. Proper syntax of SvcParamValue
-    /// is described in Appendix A of [I-D.ietf-dnsop-svcb-https].
-    ///
-    /// @param from_wire_data used to determine whether SvcParams data comes
-    /// from unpacked wire data or from ctor param
-    ///
-    /// @throw InvalidOptionDnrSvcParams Thrown in case of any issue found when checking
-    /// @c ServiceParams field syntax
-    void checkSvcParams(bool from_wire_data = true);
-
-    /// @brief Checks IP address(es) field if data is correct and throws in case of issue found.
-    ///
-    /// Fields lengths are also calculated and saved to member variables.
-    ///
-    /// @throw OutOfRange Thrown in case of no IP addresses found or when IP addresses length
-    /// is too big
-    /// @throw InvalidOptionDnrSvcParams Thrown when @c checkSvcParams(from_wire_data) throws
-    void checkFields();
-
     /// @brief Adds IP address to @c ip_addresses_ container.
     ///
     /// @param ip_address IP address to be added
     void addIpAddress(const asiolink::IOAddress& ip_address);
 
+    /// @brief Parses a convenient notation of the option data, which may be used in config.
+    ///
+    /// As an alternative to the binary format,
+    /// we provide convenience option definition as a string in format:
+    /// (for DNRv6)
+    /// "100, dot1.example.org., 2001:db8::1 2001:db8::2, alpn=dot\\,doq\\,h2\\,h3 port=8530 dohpath=/q{?dns}"
+    /// "200, resolver.example." - ADN only mode
+    /// (for DNRv4)
+    /// "100, dot1.example.org., 10.0.3.4 10.1.5.6, alpn=dot\\,doq\\,h2\\,h3 port=8530 dohpath=/q{?dns}"
+    /// "200, resolver.example." - ADN only mode
+    ///
+    /// Note that comma and pipe chars ("," 0x2C and "|" 0x7C) are used as separators in this
+    /// syntax. That's why whenever they are used in config in fields' values, they must be escaped
+    /// with double backslash as in example.
+    ///
+    /// Note that this function parses single DnrInstance. For DNRv4 it is possible to have more
+    /// than one DnrInstance per one Option. In that case this function must be called for each
+    /// DnrInstance config.
+    ///
+    /// @param config_txt convenient notation of the option data received as string
+    ///
+    /// @throw BadValue Thrown in case parser found wrong format of received string.
+    /// @throw InvalidOptionDnrDomainName Thrown in case parser had problems with extracting ADN
+    /// FQDN.
+    void parseDnrInstanceConfigData(const std::string& config_txt);
+
 protected:
     /// @brief Either V4 or V6 Option universe.
     Option::Universe universe_;
@@ -355,7 +350,7 @@ protected:
     uint16_t adn_length_;
 
     /// @brief Length of included IP addresses in octets.
-    uint16_t addr_length_ = 0;
+    uint16_t addr_length_;
 
     /// @brief Vector container holding one or more IP addresses.
     ///
@@ -366,24 +361,39 @@ protected:
     AddressContainer ip_addresses_;
 
     /// @brief Length of Service Parameters field in octets.
-    uint16_t svc_params_length_ = 0;
+    uint16_t svc_params_length_;
 
     /// @brief Flag stating whether ADN only mode is used or not.
     ///
     /// "Addr Length", "IP(v4/v6) Address(es)", and "Service Parameters (SvcParams)"
     /// fields are not present if the ADN-only mode is used.
-    bool adn_only_mode_ = true;
+    bool adn_only_mode_;
 
-    /// @brief Service Parameters (SvcParams) (variable length).
+    /// @brief Service Parameters (SvcParams) (variable length) as on-wire data buffer.
     ///
     /// Specifies a set of service parameters that are encoded
-    /// following the rules in Section 2.1 of [I-D.ietf-dnsop-svcb-https].
-    std::string svc_params_;
+    /// following the rules in Section 2.2 of RFC9460.
+    OptionBuffer svc_params_buf_;
+
+    /// @brief Service Parameters stored in a map.
+    ///
+    /// A set of service parameters that are encoded following the same rules
+    /// for encoding SvcParams using the wire format specified in Section 2.2 of RFC9460.
+    /// SvcParams are stored here in a map where the key is the SvcParamKey as an uint_16.
+    /// (Defined values are in Section 14.3.2 of RFC9460 - listed in @c SVC_PARAMS).
+    /// The value is an OpaqueDataTuple containing:
+    /// - the length of the SvcParamValue as an uint_16 integer in network byte order
+    /// - data buffer with the SvcParamValue in a format determined by the SvcParamKey.
+    std::map<uint16_t, OpaqueDataTuple> svc_params_map_;
 
     /// @brief Calculates and returns length of DNR Instance data in octets.
     /// @return length of DNR Instance data in octets.
     uint16_t dnrInstanceLen() const;
 
+    /// @brief Indicates whether the "alpn" SvcParam contains support for HTTP.
+    /// Defaults to false.
+    bool alpn_http_;
+
 private:
     /// @brief Size in octets of DNR Instance Data Length field.
     ///
@@ -412,12 +422,60 @@ private:
     ///
     /// @note It must be called in all types of constructors of class @c DnrInstance .
     void initMembers();
+
+    /// @brief Returns string representation of SvcParamVal.
+    ///
+    /// @param svc_param a key-val pair from the @c svc_params_map_ map
+    ///
+    /// @return string representation of the SvcParamVal
+    ///
+    /// @throw BadValue thrown when there is a problem with reading alpn SvcParamVal from
+    ///                 @c svc_params_map_
+    std::string svcParamValAsText(const std::pair<uint16_t, OpaqueDataTuple>& svc_param) const;
+
+    /// @brief Parses DNR resolver IP address(es) from a piece of convenient notation option config.
+    ///
+    /// @param txt_addresses a piece of convenient notation option config holding IP address(es)
+    ///
+    /// @throw BadValue Thrown in case parser found wrong format of received string.
+    void parseIpAddresses(const std::string& txt_addresses);
+
+    /// @brief Parses Service Parameters from a piece of convenient notation option config.
+    ///
+    /// @param txt_svc_params a piece of convenient notation option config holding SvcParams
+    ///
+    /// @throw InvalidOptionDnrSvcParams Thrown in case parser had problems with extracting
+    /// SvcParams.
+    void parseSvcParams(const std::string& txt_svc_params);
+
+    /// @brief Parses ALPN Service Parameter from a piece of convenient notation option config.
+    ///
+    /// @param svc_param_val a piece of convenient notation option config holding ALPN SvcParam
+    ///
+    /// @throw InvalidOptionDnrSvcParams Thrown in case parser had problems with extracting
+    /// SvcParams.
+    void parseAlpnSvcParam(const std::string& svc_param_val);
+
+    /// @brief Parses Port Service Parameter from a piece of convenient notation option config.
+    ///
+    /// @param svc_param_val a piece of convenient notation option config holding Port SvcParam
+    ///
+    /// @throw InvalidOptionDnrSvcParams Thrown in case parser had problems with extracting
+    /// SvcParams.
+    void parsePortSvcParam(const std::string& svc_param_val);
+
+    /// @brief Parses Dohpath Service Parameter from a piece of convenient notation option config.
+    ///
+    /// @param svc_param_val a piece of convenient notation option config holding Dohpath SvcParam
+    ///
+    /// @throw InvalidOptionDnrSvcParams Thrown in case parser had problems with extracting
+    /// SvcParams.
+    void parseDohpathSvcParam(const std::string& svc_param_val);
 };
 
 /// @brief Represents DHCPv4 Encrypted DNS %Option (code 162).
 ///
-/// This option has been defined in the @c draft-ietf-add-dnr (to be replaced
-/// with published RFC) and it has a following structure:
+/// This option has been defined in the @c RFC9463 and it has a following structure:
 /// - option-code = 162 (1 octet)
 /// - option-len (1 octet)
 /// - multiple (one or more) DNR Instance Data
@@ -443,20 +501,17 @@ public:
     /// @param begin Iterator pointing to the beginning of the buffer holding an
     /// option.
     /// @param end Iterator pointing to the end of the buffer holding an option.
+    /// @param convenient_notation Flag stating whether data in buffer is a convenient
+    ///                            notation string that needs custom parsing or binary
+    ///                            data. Defaults to @c false.
     ///
     /// @throw OutOfRange Thrown in case of truncated data. May be also thrown when
     /// @c DnrInstance::unpackDnrInstanceDataLength(begin,end) throws.
     /// @throw BadValue Thrown when @c DnrInstance::unpackAdn(begin,end) throws.
     /// @throw InvalidOptionDnrDomainName Thrown when @c DnrInstance::unpackAdn(begin,end) throws.
-    Option4Dnr(OptionBufferConstIter begin, OptionBufferConstIter end);
-
-    /// @brief Constructor of the empty %Option.
-    ///
-    /// No DNR instances are included in the %Option when using this ctor.
-    /// They must be added afterwards.
-    /// No fields data included in the %Option when using this ctor.
-    /// They must be added afterwards.
-    Option4Dnr() : Option(V4, DHO_V4_DNR) {}
+    Option4Dnr(OptionBufferConstIter begin,
+               OptionBufferConstIter end,
+               bool convenient_notation = false);
 
     /// @brief Adds given DNR instance to Option's DNR Instance container.
     /// @param dnr_instance DNR instance to be added
@@ -515,6 +570,24 @@ public:
 protected:
     /// @brief Container holding DNR Instances.
     DnrInstanceContainer dnr_instances_;
+
+private:
+    /// @brief Flag stating whether the %Option was constructed with a convenient notation string,
+    /// that needs custom parsing, or binary data.
+    bool convenient_notation_;
+
+    /// @brief Parses a convenient notation of the option data, which may be used in config.
+    ///
+    /// As an alternative to the binary format,
+    /// we provide convenience option definition as a string in format:
+    /// "name": "v4-dnr",
+    /// "data": "10, dot1.example.org., 10.0.2.3 10.3.4.5, alpn=dot\\,doq | 20, dot2.example.org., 10.0.2.3 10.3.4.5, alpn=dot"
+    ///
+    /// It may throw BadValue, InvalidOptionDnrDomainName or InvalidOptionDnrSvcParams,
+    /// if DnrInstance#parseDnrInstanceConfigData() throws.
+    ///
+    /// @param config_txt convenient notation of the option data received as string.
+    void parseConfigData(const std::string& config_txt);
 };
 
 /// A pointer to the @c OptionDnr4 object.
