@@ -28,13 +28,13 @@
 #include <dhcp/option_string.h>
 #include <dhcp/option_vendor.h>
 #include <dhcp/option_vendor_class.h>
-#include <util/encode/hex.h>
+#include <util/encode/encode.h>
 #include <dns/labelsequence.h>
 #include <dns/name.h>
 #include <util/strutil.h>
 #include <boost/algorithm/string/classification.hpp>
-#include <boost/algorithm/string/join.hpp>
 #include <boost/algorithm/string/predicate.hpp>
+#include <boost/algorithm/string/replace.hpp>
 #include <boost/dynamic_bitset.hpp>
 #include <boost/make_shared.hpp>
 #include <sstream>
@@ -317,7 +317,27 @@ OptionDefinition::optionFactory(Option::Universe u, uint16_t type,
             // convenient notation option config that needs special parsing. Let's treat it like
             // String type. optionFactory() will be called with convenient_notation flag set to
             // true, so that the factory will have a chance to handle it in a special way.
-            writeToBuffer(u, boost::algorithm::join(values, ","), OPT_STRING_TYPE, buf);
+
+            // At this stage any escape backslash chars were lost during last call of
+            // isc::util::str::tokens() inside of
+            // OptionDataParser::createOption(ConstElementPtr option_data), so we must
+            // restore them. Some INTERNAL options may use escaped delimiters, e.g. DNR options.
+            // Values are concatenated back to comma separated format and will be written to
+            // the OptionBuffer as one String type option.
+            std::ostringstream stream;
+            bool first = true;
+            for (auto val : values) {
+                boost::algorithm::replace_all(val, ",", "\\,");
+                if (first) {
+                    first = false;
+                } else {
+                    stream << ",";
+                }
+
+                stream << val;
+            }
+
+            writeToBuffer(u, stream.str(), OPT_STRING_TYPE, buf);
         } else {
             writeToBuffer(u, util::str::trim(values[0]), type_, buf);
         }
@@ -893,7 +913,7 @@ OptionDefinition::factorySpecialFormatOption(Option::Universe u,
             return (OptionPtr(new Option6PDExclude(begin, end)));
 
         case D6O_V6_DNR:
-            return (OptionPtr(new Option6Dnr(begin, end)));
+            return (OptionPtr(new Option6Dnr(begin, end, convenient_notation)));
 
         default:
             break;
@@ -927,7 +947,7 @@ OptionDefinition::factorySpecialFormatOption(Option::Universe u,
             return (factoryOpaqueDataTuples(Option::V4, getCode(), begin, end, OpaqueDataTuple::LENGTH_2_BYTES));
 
         case DHO_V4_DNR:
-            return (OptionPtr(new Option4Dnr(begin, end)));
+            return (OptionPtr(new Option4Dnr(begin, end, convenient_notation)));
 
         default:
             break;
