@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -8,7 +8,7 @@
 
 #include <exceptions/exceptions.h>
 #include <dhcp/dhcp6.h>
-#include <dhcp/tests/iface_mgr_test_config.h>
+#include <dhcp/testutils/iface_mgr_test_config.h>
 #include <dhcpsrv/cfgmgr.h>
 #include <dhcpsrv/lease_mgr_factory.h>
 #include <dhcpsrv/subnet_id.h>
@@ -16,7 +16,6 @@
 #include <process/logging_info.h>
 #include <stats/stats_mgr.h>
 #include <util/chrono_time_utils.h>
-#include <testutils/env_var_wrapper.h>
 
 #include <gtest/gtest.h>
 
@@ -33,7 +32,6 @@ using namespace isc::dhcp::test;
 using namespace isc::util;
 using namespace isc::stats;
 using namespace isc::process;
-using namespace isc::test;
 using namespace isc;
 
 namespace {
@@ -257,8 +255,9 @@ TEST(ValueStorageTest, StringTesting) {
 
 class CfgMgrTest : public ::testing::Test {
 public:
-    CfgMgrTest() : data_dir_env_var_("KEA_DHCP_DATA_DIR") {
+    CfgMgrTest() {
         // make sure we start with a clean configuration
+        original_datadir_ = CfgMgr::instance().getDataDir();
         clear();
     }
 
@@ -278,26 +277,12 @@ public:
     }
 
     void clear() {
-        data_dir_env_var_.setValue();
         CfgMgr::instance().setFamily(AF_INET);
-        resetDataDir();
+        CfgMgr::instance().setDataDir(original_datadir_);
         CfgMgr::instance().clear();
         LeaseMgrFactory::destroy();
     }
 
-    /// @brief Sets the DHCP data path for server data files.
-    /// @param custom_path path to use.
-    void setDataDir(const std::string explicit_path = "") {
-        CfgMgr::instance().getDataDir(true,
-                                      (!explicit_path.empty() ?
-                                      explicit_path : std::string(DHCP_DATA_DIR)));
-    }
-
-    /// @brief Resets the DHCP data path to DHCP_DATA_DIR.
-    void resetDataDir() {
-        CfgMgr::instance().getDataDir(true);
-    }
-
     /// @brief Creates instance of the backend.
     ///
     /// @param family AF_INET for v4, AF_INET6 for v6
@@ -315,16 +300,18 @@ public:
         CfgMgr::instance().setFamily(family);
     }
 
-    /// @brief RAII wrapper for KEA_DHCP_DATA_DIR env variable.
-    EnvVarWrapper data_dir_env_var_;
-
     /// used in client classification (or just empty container for other tests)
     isc::dhcp::ClientClasses classify_;
+
+private:
+    /// to restore it in destructor.
+    string original_datadir_;
 };
 
 // Checks that there is a configuration structure available and that
 // it is empty by default.
 TEST_F(CfgMgrTest, configuration) {
+
     ConstSrvConfigPtr configuration = CfgMgr::instance().getCurrentCfg();
     ASSERT_TRUE(configuration);
     EXPECT_TRUE(configuration->getLoggingInfo().empty());
@@ -334,18 +321,62 @@ TEST_F(CfgMgrTest, configuration) {
     EXPECT_TRUE(configuration->getLoggingInfo().empty());
 }
 
-TEST_F(CfgMgrTest, getDataDir) {
-    // No environment variable or explicit path should
-    // return the default path after construction.
-    ASSERT_FALSE(getenv("KEA_DHCP_DATA_DIR"));
-    ASSERT_EQ(CfgMgr::instance().getDataDir(), std::string(DHCP_DATA_DIR));
+// This test checks the data directory handling.
+TEST_F(CfgMgrTest, dataDir) {
+    // It is only in DHCPv6 syntax so switch to IPv6.
+    CfgMgr::instance().setFamily(AF_INET6);
 
-    setenv("KEA_DHCP_DATA_DIR", "/tmp/envpath", 1);
-    ASSERT_EQ(CfgMgr::instance().getDataDir(true), "/tmp/envpath");
-    ASSERT_EQ(CfgMgr::instance().getDataDir(), "/tmp/envpath");
+    // Default.
+    EXPECT_TRUE(CfgMgr::instance().getDataDir().unspecified());
+    ConstElementPtr json = CfgMgr::instance().getCurrentCfg()->toElement();
+    ASSERT_TRUE(json);
+    ASSERT_EQ(Element::map, json->getType());
+    ConstElementPtr dhcp = json->get("Dhcp6");
+    ASSERT_TRUE(dhcp);
+    ASSERT_EQ(Element::map, dhcp->getType());
+    ConstElementPtr datadir = dhcp->get("data-directory");
+    EXPECT_FALSE(datadir);
 
-    ASSERT_EQ(CfgMgr::instance().getDataDir(true, "/tmp/explicit"), "/tmp/explicit");
-    ASSERT_EQ(CfgMgr::instance().getDataDir(), "/tmp/explicit");
+    // Set but not specified.
+    CfgMgr::instance().setDataDir("/tmp");
+    EXPECT_TRUE(CfgMgr::instance().getDataDir().unspecified());
+    EXPECT_EQ("/tmp", string(CfgMgr::instance().getDataDir()));
+    json = CfgMgr::instance().getCurrentCfg()->toElement();
+    ASSERT_TRUE(json);
+    ASSERT_EQ(Element::map, json->getType());
+    dhcp = json->get("Dhcp6");
+    ASSERT_TRUE(dhcp);
+    ASSERT_EQ(Element::map, dhcp->getType());
+    datadir = dhcp->get("data-directory");
+    EXPECT_FALSE(datadir);
+
+    // Set and specified.
+    CfgMgr::instance().setDataDir("/tmp", false);
+    EXPECT_FALSE(CfgMgr::instance().getDataDir().unspecified());
+    EXPECT_EQ("/tmp", string(CfgMgr::instance().getDataDir()));
+    json = CfgMgr::instance().getCurrentCfg()->toElement();
+    ASSERT_TRUE(json);
+    ASSERT_EQ(Element::map, json->getType());
+    dhcp = json->get("Dhcp6");
+    ASSERT_TRUE(dhcp);
+    ASSERT_EQ(Element::map, dhcp->getType());
+    datadir = dhcp->get("data-directory");
+    ASSERT_TRUE(datadir);
+    ASSERT_EQ(Element::string, datadir->getType());
+    EXPECT_EQ("/tmp", datadir->stringValue());
+
+    // Still IPv6 only.
+    CfgMgr::instance().setFamily(AF_INET);
+    EXPECT_FALSE(CfgMgr::instance().getDataDir().unspecified());
+    EXPECT_EQ("/tmp", string(CfgMgr::instance().getDataDir()));
+    json = CfgMgr::instance().getCurrentCfg()->toElement();
+    ASSERT_TRUE(json);
+    ASSERT_EQ(Element::map, json->getType());
+    dhcp = json->get("Dhcp4");
+    ASSERT_TRUE(dhcp);
+    ASSERT_EQ(Element::map, dhcp->getType());
+    datadir = dhcp->get("data-directory");
+    EXPECT_FALSE(datadir);
 }
 
 // This test checks the D2ClientMgr wrapper methods.
