@@ -1,4 +1,4 @@
-// Copyright (C) 2010-2016 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2010-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -14,7 +14,7 @@
 
 #include <boost/lexical_cast.hpp>
 
-#include <util/encode/base64.h>
+#include <util/encode/encode.h>
 #include <util/buffer.h>
 #include <util/time_utilities.h>
 #include <dns/messagerenderer.h>
