@@ -1,4 +1,4 @@
-// Copyright (C) 2010-2021 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2010-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -16,7 +16,7 @@
 #include <cryptolink/cryptolink.h>
 
 #include <dns/name.h>
-#include <util/encode/base64.h>
+#include <util/encode/encode.h>
 #include <dns/tsigkey.h>
 
 #include <boost/lexical_cast.hpp>
